@@ -1,5 +1,5 @@
 package Archive::BagIt::Fast;
-$Archive::BagIt::Fast::VERSION = '0.042';
+$Archive::BagIt::Fast::VERSION = '0.044';
 use parent "Archive::BagIt";
 
 use IO::AIO;
@@ -10,7 +10,7 @@ Archive::BagIt::Fast - For people who are willing to rely on some other modules
 
 =head1 VERSION
 
-version 0.042
+version 0.044
 
 =cut
 
@@ -26,9 +26,12 @@ sub verify_bag {
     my $payload_dir   = "$bagit/data";
     my %manifest      = ();
     my $return_all_errors = $opts->{return_all_errors};
+    my $MMAP_MIN = $opts->{mmap_min} || 8000000;
     my %invalids;
     my @payload       = ();
 
+  
+
     die("$manifest_file is not a regular file") unless -f ($manifest_file);
     die("$payload_dir is not a directory") unless -d ($payload_dir);
 
@@ -54,7 +57,7 @@ sub verify_bag {
 
         open(my $fh, "<:raw", "$bagit/$local_name") or die ("Cannot open $local_name");
         stat $fh;
-        if (-s _ < 8000000) {
+        if (-s _ < $MMAP_MIN ) {
           sysread $fh, my $data, -s _;
           $digest = $digestobj->add($data)->hexdigest;
         }
